@@ -9,21 +9,21 @@ class Client:
     _password = None
     _token = None
 
-    def __init__(self, login, password):
-        self._login = login
+    def __init__(self, username, password):
+        self._username = username
         self._password = password
         self._check_creds()
 
     @property
-    def login(self):
-        return self._login
+    def username(self):
+        return self._username
 
     @property
     def password(self):
         return self._password
 
     def _check_creds(self):
-        payload = {"username": self._login, "password": self._password}
+        payload = {"username": self._username, "password": self._password}
         r = requests.post(url=BASE_URL + "auth", params=payload)
         print(r)
         if r.status_code == 200:
